@@ -341,7 +341,7 @@ public class I2PSnarkUtil implements DisconnectListener {
             if (opts.getProperty(I2PClient.PROP_SIGTYPE) == null)
                 opts.setProperty(I2PClient.PROP_SIGTYPE, "EdDSA_SHA512_Ed25519");
             if (opts.getProperty("i2cp.leaseSetEncType") == null)
-                opts.setProperty("i2cp.leaseSetEncType", "4,0");
+                opts.setProperty("i2cp.leaseSetEncType", "4");
             // assume compressed content
             if (opts.getProperty(I2PClient.PROP_GZIP) == null)
                 opts.setProperty(I2PClient.PROP_GZIP, "false");
