@@ -10,6 +10,9 @@ package net.i2p.router.web.helpers;
 
 import java.io.File;
 import java.io.IOException;
+import java.io.InputStream;
+import java.io.InputStreamReader;
+import java.io.Reader;
 import java.io.Serializable;
 import java.io.Writer;
 import java.math.BigInteger;         // debug
@@ -58,6 +61,7 @@ import net.i2p.util.Addresses;
 import net.i2p.util.ConvertToHash;
 import net.i2p.util.Log;
 import net.i2p.util.ObjectCounterUnsafe;
+import net.i2p.util.SystemVersion;
 import net.i2p.util.Translate;
 import net.i2p.util.VersionComparator;
 
@@ -707,6 +711,8 @@ class NetDbRenderer {
         int rapCount = 0;
         BigInteger median = null;
         int c = 0;
+        boolean linkSusi = _context.portMapper().isRegistered("susidns");
+        long now = _context.clock().now();
 
         // Summary
         if (debug) {
@@ -721,61 +727,12 @@ class NetDbRenderer {
                 TunnelPoolSettings in = _context.tunnelManager().getInboundSettings(myLeaseSet.getHash());
                 if (in != null && in.getDestinationNickname() != null)
                     buf.append("  -  ").append(DataHelper.escapeHTML(in.getDestinationNickname()));
-                buf.append("</th><th></th></tr>\n");
-                boolean unpublished = ! _context.clientManager().shouldPublishLeaseSet(myLeaseSet.getHash());
-                if (unpublished) {
-                    buf.append("<tr><th colspan=\"3\">").append(_t("Local")).append(" ");
-                    if (myLeaseSet.getType() == DatabaseEntry.KEY_TYPE_ENCRYPTED_LS2 || _context.keyRing().get(myLeaseSet.getHash()) != null)
-                        buf.append(" <b>(").append(_t("Encrypted")).append(")</b>");
-                    buf.append(_t("Unpublished")).append(" ");
-                } else {
-                    buf.append("<tr><th colspan=\"3\">").append(_t("Local")).append(" ");
-                    if (myLeaseSet.getType() == DatabaseEntry.KEY_TYPE_ENCRYPTED_LS2 || _context.keyRing().get(myLeaseSet.getHash()) != null)
-                        buf.append(" <b>(").append(_t("Encrypted")).append(")</b>");
-                    buf.append(_t("Published")).append(" ");
-                    long exp = 0;
-                    long now = _context.clock().now();
-                    if (myLeaseSet.getType() != DatabaseEntry.KEY_TYPE_LEASESET) {
-                        LeaseSet2 ls2 = (LeaseSet2) myLeaseSet;
-                        long pub = now - ls2.getPublished();
-                        buf.append(_t("{0} ago", DataHelper.formatDuration2(pub)));
-                        exp = ls2.getExpires()-now;
-                        buf.append(" - ");
-                    } else {
-                        exp = myLeaseSet.getLatestLeaseDate() - now;
-                    }
-                    if (exp > 0)
-                            buf.append(_t("Expires in {0}", DataHelper.formatDuration2(exp)));
-                        else
-                            buf.append(_t("Expired {0} ago", DataHelper.formatDuration2(0-exp)));
-                }
-                buf.append("</th><th></th></tr>\n");
-                buf.append("\n<tr><td colspan=\"2\"><ul class=\"netdb_leases\">");
-                boolean isMeta = myLeaseSet.getType() == DatabaseEntry.KEY_TYPE_META_LS2;
-                for (int i = 0; i < myLeaseSet.getLeaseCount(); i++) {
-                    Lease lease = myLeaseSet.getLease(i);
-                    buf.append("<li><b>").append(_t("Lease")).append(' ').append(i + 1).append(":</b> <span class=\"tunnel_peer\">");
-                    buf.append(_context.commSystem().renderPeerHTML(lease.getGateway()));
-                    buf.append("</span> ");
-                    if (!isMeta) {
-                        buf.append("<span class=\"netdb_tunnel\">").append(_t("Tunnel")).append(" <span class=\"tunnel_id\">")
-                        .append(lease.getTunnelId().getTunnelId()).append("</span></span> ");
-                    }
-                    if (debug) {
-                        long now = _context.clock().now();
-                        long exl = lease.getEndTime() - now;
-                        buf.append("<b class=\"netdb_expiry\">");
-                        if (exl > 0)
-                            buf.append(_t("Expires in {0}", DataHelper.formatDuration2(exl)));
-                        else
-                            buf.append(_t("Expired {0} ago", DataHelper.formatDuration2(0-exl)));
-                        buf.append("</b>");
-                    }
-                    buf.append("</li>");
-                }
-                buf.append("</ul></td></tr>\n");
+                buf.append("</th><th></th></tr>\n" +
+                           "<tr><td colspan=\"3\">\n");
+                renderLeaseSet(buf, myLeaseSet, true, now, linkSusi, null);
+                buf.append("</td></tr>\n");
             }
-            buf.append("<tr><td><b>Total Known Remote Leasesets:</b></td><td colspan=\"3\">").append(leases.size()-1).append("</td></tr>\n");
+            buf.append("<tr><td><b>Total Known Remote Leasesets:</b></td><td colspan=\"3\">").append(Math.max(leases.size()-1, 0)).append("</td></tr>\n");
         } else {
             buf.append("<tr><th colspan=\"3\">Leaseset Summary for Floodfill</th>" +
                        "<th><a href=\"/configadvanced\" title=\"").append(_t("Manually Configure Floodfill Participation")).append("\">[")
@@ -817,8 +774,6 @@ class NetDbRenderer {
             medianCount = rapCount / 2;
           }
 
-          boolean linkSusi = _context.portMapper().isRegistered("susidns");
-          long now = _context.clock().now();
           buf.append("<div class=\"leasesets_container\">");
           boolean ldebug = debug || client != null;
           for (LeaseSet ls : leases) {
@@ -948,7 +903,7 @@ class NetDbRenderer {
                     buf.append("<a href=\"http://").append(b32).append("\">").append(b32).append("</a></td>");
                     if (linkSusi && !unpublished && host == null) {
                         buf.append("<td class=\"addtobook\" colspan=\"2\">").append("<a title=\"").append(_t("Add to address book"))
-                           .append("\" href=\"/susidns/addressbook.jsp?book=private&amp;destination=")
+                           .append("\" href=\"/dns?book=private&amp;destination=")
                            .append(dest.toBase64()).append("#add\">").append(_t("Add to local address book")).append("</a></td>");
                     } // else probably a client
                 }
@@ -971,7 +926,7 @@ class NetDbRenderer {
                     buf.append("><a href=\"http://").append(b32).append("\">").append(b32).append("</a></td>\n");
                     if (linkSusi && dest != null) {
                        buf.append("<td class=\"addtobook\"><a title=\"").append(_t("Add to address book"))
-                       .append("\" href=\"/susidns/addressbook.jsp?book=private&amp;destination=")
+                       .append("\" href=\"/dns?book=private&amp;destination=")
                        .append(dest.toBase64()).append("#add\">").append(_t("Add to local address book")).append("</a></td>");
                     }
                 }
@@ -1076,6 +1031,7 @@ class NetDbRenderer {
     /**
      *  @param mode 0: charts only; 1: full routerinfos; 2: abbreviated routerinfos
      *         mode 3: Same as 0 but sort countries by count
+     *         Codes greater than 16 are map codes * 16
      */
     public void renderStatusHTML(Writer out, int pageSize, int page, int mode) throws IOException {
         if (!_context.netDb().isInitialized()) {
@@ -1184,7 +1140,28 @@ class NetDbRenderer {
         // the summary table
         buf.append("<table id=\"netdboverview\" border=\"0\" cellspacing=\"30\"><tr><th colspan=\"3\">");
         buf.append(_t("Network Database Router Statistics"));
-        buf.append("</th></tr><tr><td style=\"vertical-align: top;\">");
+        buf.append("</th></tr>");
+        if (!SystemVersion.isSlow() && !_context.commSystem().isDummy()) {
+            // svg inline part 1
+            out.append(buf);
+            buf.setLength(0);
+            buf.append("<tr><td id=\"mapcontainer\" colspan=\"3\">");
+            boolean ok = embedResource(buf, "mapbase75p1.svg");
+            if (ok) {
+                out.append(buf);
+                buf.setLength(0);
+                // overlay
+                MapMaker mm = new MapMaker(_context);
+                out.write(mm.render(mode >> 4));
+                // svg inline part 2
+                embedResource(buf, "mapbase75p2.svg");
+                buf.append("</td></tr>");
+                out.append(buf);
+            }
+            buf.setLength(0);
+        }
+        mode &= 0x0f;
+        buf.append("<tr><td style=\"vertical-align: top;\">");
         // versions table
         List<String> versionList = new ArrayList<String>(versions.objects());
         if (!versionList.isEmpty()) {
@@ -1288,6 +1265,30 @@ class NetDbRenderer {
         out.flush();
     }
 
+    /**
+     * @return success
+     * @since 0.9.66
+     */
+    private boolean embedResource(StringBuilder buf, String rsc) {
+        InputStream is = this.getClass().getResourceAsStream("/net/i2p/router/web/resources/" + rsc);
+        if (is == null)
+            return false;
+        Reader br = null;
+        try {
+            br = new InputStreamReader(is, "UTF-8");
+            char[] c = new char[4096];
+            int read;
+            while ( (read = br.read(c)) >= 0) {
+                buf.append(c, 0, read);
+            }
+        } catch (IOException ioe) {
+            return false;
+        } finally {
+            if (br != null) try { br.close(); } catch (IOException ioe) {}
+        }
+        return true;
+    }
+
     /**
      * Countries now in a separate bundle
      * @param code two-letter country code
