@@ -155,7 +155,7 @@ class SummaryBarRenderer {
         Map<String, String> svcs = new TreeMap<String, String>(Collator.getInstance());
         StringBuilder rbuf = new StringBuilder(128);
 
-        String tx = _t("Changelog");
+        String tx = _t("Change Log");
         rbuf.append("<a href=\"/viewhistory\" target=\"_top\" title=\"")
            .append(_t("Recent development changes to the router"))
            .append("\">")
@@ -268,7 +268,7 @@ class SummaryBarRenderer {
                 String url = urls.get(i);
                 String txp = sz > 1 ? tx + ' ' + (i + 1) : tx;
                 rbuf.setLength(0);
-                rbuf.append("<tr><td><img src=\"/themes/console/images/server.png\" height=\"16\" width=\"16\" alt=\"\"></td><td align=\"left\">" +
+                rbuf.append("<tr><td><img src=\"/themes/console/images/jetty.png\" height=\"16\" width=\"16\" alt=\"\"></td><td align=\"left\">" +
                             "<a href=\"")
                     .append(url)
                     .append("\" target=\"_blank\" title=\"")
@@ -371,8 +371,14 @@ class SummaryBarRenderer {
                 .append(_t("Manage your I2P hosts file here (I2P domain name resolution)"))
                 .append("\">")
                 .append(nbsp(tx));
-            addBubble(rbuf, PortMapper.SVC_SUSIDNS);
             rbuf.append("</a>\n");
+            StringBuilder bbuf = new StringBuilder(128);
+            addBubble(bbuf, PortMapper.SVC_SUSIDNS);
+            if (bbuf.length() > 0) {
+                rbuf.append("<a href=\"/dns?book=router&amp;filter=latest\" target=\"_top\">");
+                rbuf.append(bbuf);
+                rbuf.append("</a>\n");
+            }
             svcs.put(tx, rbuf.toString());
         }
 
@@ -529,11 +535,11 @@ class SummaryBarRenderer {
         svcs.put(tx, rbuf.toString());
 */
 
-        String tx = _t("Changelog");
+        String tx = _t("Change Log");
         rbuf.setLength(0);
         rbuf.append("<a title=\"")
-           .append(_t("View full changelog"))
-           .append("\" href=\"/viewhistory\" target=\"_blank\">")
+           .append(_t("View full change log"))
+           .append("\" href=\"/viewhistory\" target=\"_top\">")
            .append(nbsp(tx))
            .append("</a>\n");
         svcs.put(tx, rbuf.toString());
