@@ -1345,7 +1345,8 @@ public class Router implements RouterClock.ClockShiftListener {
         KeyManager.DEFAULT_KEYDIR + '/' + KeyManager.KEYFILE_PUBLIC_ENC,
         KeyManager.DEFAULT_KEYDIR + '/' + KeyManager.KEYFILE_PRIVATE_SIGNING,
         KeyManager.DEFAULT_KEYDIR + '/' + KeyManager.KEYFILE_PUBLIC_SIGNING,
-        "sessionKeys.dat"     // no longer used
+        "sessionKeys.dat",    // no longer used
+        "ssu2tokens.txt"
     };
 
     /**
@@ -1595,6 +1596,15 @@ public class Router implements RouterClock.ClockShiftListener {
             saveConfig("router.previousVersion", RouterVersion.VERSION);
         }
 
+        // If we are ff, are restarting, and configured for auto-ff,
+        // put a note in the config. FloodfillMonitorJob will check for
+        // and remove this config at startup.
+        if (_context.netDb().floodfillEnabled() &&
+            (exitCode == EXIT_HARD_RESTART || exitCode == EXIT_GRACEFUL_RESTART) &&
+            "auto".equals(_context.getProperty(FloodfillNetworkDatabaseFacade.PROP_FLOODFILL_PARTICIPANT, "auto"))) {
+            saveConfig(FloodfillNetworkDatabaseFacade.PROP_FLOODFILL_AT_RESTART, "true");
+        }
+
         _context.removeShutdownTasks();
 
         // All in-JVM clients should be gone by now,
